-- Define constants for keyboard dimensions and padding
local landscapeKeyboardX = 10
local landscapeKeyboardY = 900
local portraitKeyboardX = 100
local portraitKeyboardY = 250
--local keyWidth = 50
--local keyHeight = 50
local keyPadding = 5

-- Determine the orientation and set keyboard position accordingly
function updateKeyboardPosition()
    local width, height = love.graphics.getDimensions()
    if KeyboardOrientation == "portrait" then
        touchKeyboard.x = portraitKeyboardX
        touchKeyboard.y = portraitKeyboardY
        touchKeyboard.rotation = 0
    elseif KeyboardOrientation == "landscape" then
        touchKeyboard.x = landscapeKeyboardX
        touchKeyboard.y = landscapeKeyboardY
        touchKeyboard.rotation = math.pi / 2 -- Rotate 90 degrees
        
    end
end

local touchX, touchY = 0, 0
function touchKeyboard:update(dt)
    updateKeyboardPosition()

    if touchControls.layout == "keyboard" then
        -- Update transparency for keys
        for key, transparency in pairs(self.keyTransparency) do
            if transparency > 0 then
                self.keyTransparency[key] = transparency - dt * self.transparencyDecreaseRate
            end

            if self.selectedKey == nil and self.keyTransparency[key] < 0.1 then
                self.keyTransparency[key] = nil
            end
        end

        -- Check for touch or mouse input
        local touches = love.touch.getTouches()
        if #touches == 0 and love.mouse.isDown(1) then
            local x, y = love.mouse.getPosition()
            if MobileOrientation == "landscape" then
                x, y = love.graphics.inverseTransformPoint(x, y)
            end
            touchKeyboard:touchpressed(x, y)
        else
            for i, touchID in ipairs(touches) do
                local touchX, touchY = love.touch.getPosition(touchID)
                touchKeyboard:touchpressed(touchX, touchY)
            end
        end

        -- Check if space key is pressed
        local layout = selectKeyboardLayout()
        for i, row in ipairs(layout) do
            for j, key in ipairs(row) do
                if key == "Space" then
                    local keyX = (j - 1) * (keyWidth + keyPadding)
                    local keyY = (i - 1) * (keyHeight + keyPadding)
                    if self.selectedKey == nil and touchX >= keyX and touchX <= keyX + keyWidth * 3 + keyPadding * 2
                        and touchY >= keyY and touchY <= keyY + keyHeight then
                        -- Space key is pressed
                        self.selectedKey = key
                        print("Space Key Pressed")
                        love.system.vibrate(0.1) -- Add mobile vibration (if supported)
                    end
                end
            end
        end

        local selectedKey = touchKeyboard:getSelectedKey()
        if selectedKey then
            --print("Selected Key:", selectedKey)
        end
    end

    return selectedKey
end

